@@ -1,7 +1,7 @@
 use strict;
 use warnings;
-package Software::License::BSD;
-$Software::License::BSD::VERSION = '0.104003';
+package Software::License::BSD 0.104006;
+
 use parent 'Software::License';
 # ABSTRACT: The (three-clause) BSD License
 
@@ -9,7 +9,7 @@ sub name { 'The (three-clause) BSD License' }
 sub url  { 'http://opensource.org/licenses/BSD-3-Clause' }
 sub meta_name  { 'bsd' }
 sub meta2_name { 'bsd' }
-sub spdx_expression  { 'BSD' }
+sub spdx_expression  { 'BSD-3-Clause' }
 
 1;
 
@@ -23,7 +23,7 @@ Software::License::BSD - The (three-clause) BSD License
 
 =head1 VERSION
 
-version 0.104003
+version 0.104006
 
 =head1 PERL VERSION
 
@@ -41,11 +41,11 @@ lower the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023 by Ricardo Signes.
+This software is copyright (c) 2024 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
