@@ -1,15 +1,15 @@
 use strict;
 use warnings;
-package Software::License::SSLeay 0.104005;
+package Software::License::SSLeay 0.104006;
 
 use parent 'Software::License';
 # ABSTRACT: The Original SSLeay License
 
 sub name { 'Original SSLeay License' }
-sub url  { 'http://h71000.www7.hp.com/doc/83final/BA554_90007/apcs02.html' }
+sub url  { 'http://h41379.www4.hpe.com/doc/83final/ba554_90007/apcs02.html' }
 sub meta_name  { 'unrestricted' }
 sub meta2_name { 'ssleay' }
-sub spdx_expression  { 'SSLeay' }
+sub spdx_expression  { undef } # Not known to SPDX
 
 1;
 
@@ -23,7 +23,7 @@ Software::License::SSLeay - The Original SSLeay License
 
 =head1 VERSION
 
-version 0.104005
+version 0.104006
 
 =head1 PERL VERSION
 
@@ -45,7 +45,7 @@ Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023 by Ricardo Signes.
+This software is copyright (c) 2024 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
